local P4HasBeenRead = {}

P4HasBeenRead.notReadTexture = getTexture("media/ui/Item_Book_NR.png")
P4HasBeenRead.notCompletedTexture = getTexture("media/ui/Item_Book_NC.png")
P4HasBeenRead.currentTargetTexture = getTexture("media/ui/Item_Book_CT.png")
P4HasBeenRead.alreadyReadTexture = nil

P4HasBeenRead.options = {
	showNR = true,
	showNC = true,
	showAR = false,
	showNCasNR = false,
	showCT = true,
	enableCD = false,
	enableVHS = false,
	enableHVHS = false,
}

SetModOptions = function(options)
	P4HasBeenRead.options = options
end

SetTextures = function()
	if ModOptions and ModOptions.getInstance then
		P4HasBeenRead.notReadTexture = nil
		if P4HasBeenRead.options.showNR then
			P4HasBeenRead.notReadTexture = getTexture("media/ui/Item_Book_NR.png")
		end
		P4HasBeenRead.notCompletedTexture = nil
		if P4HasBeenRead.options.showNC then
			if P4HasBeenRead.options.showNCasNR then
				P4HasBeenRead.notCompletedTexture = getTexture("media/ui/Item_Book_NR.png")
			else
				P4HasBeenRead.notCompletedTexture = getTexture("media/ui/Item_Book_NC.png")
			end
		end
		P4HasBeenRead.alreadyReadTexture = nil
		if P4HasBeenRead.options.showAR then
			P4HasBeenRead.alreadyReadTexture = getTexture("media/ui/Item_Book_AR.png")
		end
		P4HasBeenRead.currentTargetTexture = nil
		if P4HasBeenRead.options.showCT then
			P4HasBeenRead.currentTargetTexture = getTexture("media/ui/Item_Book_CT.png")
		end
	end
end

P4HasBeenRead.original_render = ISInventoryPane.renderdetails
function ISInventoryPane:renderdetails(doDragged)
	if not CONDITION then
		P4HasBeenRead.original_render(self, doDragged)
	end

	local recordedMedia = nil
	if P4HasBeenRead.options.enableCD or P4HasBeenRead.options.enableVHS or P4HasBeenRead.options.enableHVHS then
		recordedMedia = getZomboidRadio():getRecordedMedia()
	end

	local recordedMediaResult = {}

	-- [NOTICE]
	-- The source code below is the basicaly same as the vanilla code in Build 41.50.
	-- Due to changes in the vanilla code, it may not work properly.

	local player = getSpecificPlayer(self.player)
	local y = 0
	local MOUSEX = self:getMouseX()
	local MOUSEY = self:getMouseY()
	local YSCROLL = self:getYScroll()
	local HEIGHT = self:getHeight()
	for k, v in ipairs(self.itemslist) do
		local count = 1
		for k2, v2 in ipairs(v.items) do
			local item = v2
			local statusTexture = nil
			local currentTargetTexture = nil
			if item:getCategory() == "Literature" then
				local skillBook = SkillBook[item:getSkillTrained()]
				if skillBook then
					local perkLevel = player:getPerkLevel(skillBook.perk)
					local minLevel = item:getLvlSkillTrained()
					local maxLevel = item:getMaxLevelTrained()
					if (minLevel <= perkLevel + 1) and (perkLevel + 1 <= maxLevel) then
						currentTargetTexture = P4HasBeenRead.currentTargetTexture
					end
					local readPages = player:getAlreadyReadPages(item:getFullType())
					if readPages >= item:getNumberOfPages() then
						statusTexture = P4HasBeenRead.alreadyReadTexture
					elseif perkLevel >= maxLevel then
						statusTexture = P4HasBeenRead.alreadyReadTexture
					elseif readPages > 0 then
						statusTexture = P4HasBeenRead.notCompletedTexture
					else
						statusTexture = P4HasBeenRead.notReadTexture
					end
				elseif item:getTeachedRecipes() and not item:getTeachedRecipes():isEmpty() then
					if player:getKnownRecipes():containsAll(item:getTeachedRecipes()) then
						statusTexture = P4HasBeenRead.alreadyReadTexture
					else
						statusTexture = P4HasBeenRead.notReadTexture
					end
				end
			elseif recordedMedia then
				local mediaData = item:getMediaData()
				if mediaData then
					local isTarget = false
					local category = mediaData:getCategory()
					if category == "CDs" and P4HasBeenRead.options.enableCD then
						isTarget = true
					elseif category == "Retail-VHS" and P4HasBeenRead.options.enableVHS then
						isTarget = true
					elseif category == "Home-VHS" and P4HasBeenRead.options.enableHVHS then
						isTarget = true
					end
					if isTarget then
						local index = mediaData:getIndex()
						statusTexture = recordedMediaResult[index]
						if statusTexture then
							if statusTexture == "mynil" then
								statusTexture = nil
							end
						else
							if recordedMedia:hasListenedToAll(player, mediaData) then
								statusTexture = P4HasBeenRead.alreadyReadTexture
							else
								statusTexture = P4HasBeenRead.notReadTexture
							end
							if statusTexture then
								recordedMediaResult[index] = statusTexture
							else
								recordedMediaResult[index] = "mynil"
							end
						end
					end
				end
			end
			if statusTexture or currentTargetTexture then
				local doIt = true
				local xoff = 0
				local yoff = 0
				local isDragging = false
				if self.dragging ~= nil and self.selected[y+1] ~= nil and self.dragStarted then
					xoff = MOUSEX - self.draggingX
					yoff = MOUSEY - self.draggingY
					if not doDragged then
						doIt = false
					else
						isDragging = true
					end
				else
					if doDragged then
						doIt = false
					end
				end
				local topOfItem = y * self.itemHgt + YSCROLL
				if not isDragging and ((topOfItem + self.itemHgt < 0) or (topOfItem > HEIGHT)) then
					doIt = false
				end
				if doIt == true then
					local tex = item:getTex()
					if tex ~= nil then
						local texWH = math.min(self.itemHgt-2,32)
						if count == 1  then
							if statusTexture then
								self:drawTexture(statusTexture, xoff+5, (y*self.itemHgt)+self.headerHgt+yoff+texWH-16, 1, 1, 1, 1)
							end
							if currentTargetTexture then
								self:drawTexture(currentTargetTexture, xoff+4, (y*self.itemHgt)+self.headerHgt+yoff-3, 1, 1, 1, 1)
							end
						elseif v.count > 2 or (doDragged and count > 1 and self.selected[(y+1) - (count-1)] == nil) then
							if statusTexture then
								self:drawTexture(statusTexture, xoff+21, (y*self.itemHgt)+self.headerHgt+yoff+texWH-16, 0.3, 1, 1, 1)
							end
							if currentTargetTexture then
								self:drawTexture(currentTargetTexture, xoff+20, (y*self.itemHgt)+self.headerHgt+yoff-3, 0.3, 1, 1, 1)
							end
						end
					end
				end
			end
			y = y + 1
			if count == 1 and self.collapsed ~= nil and v.name ~= nil and self.collapsed[v.name] then
				break
			end
			if count == 51 then
				break
			end
			count = count + 1
		end
	end
end

Events.OnGameStart.Add(SetTextures)
